import os

from google.auth.transport.requests import Request
from google.oauth2.credentials import Credentials
from google_auth_oauthlib.flow import InstalledAppFlow
from googleapiclient.discovery import build


def get_service(client_secret_json_filename):
    SCOPES = ['https://www.googleapis.com/auth/drive']
    creds = None
    if os.path.exists('token.json'):
        creds = Credentials.from_authorized_user_file('token.json', SCOPES)
    if not creds or not creds.valid:
        if creds and creds.expired and creds.refresh_token:
            creds.refresh(Request())
        else:
            flow = InstalledAppFlow.from_client_secrets_file(
                client_secret_json_filename, SCOPES)
            creds = flow.run_local_server(port=0)
        with open('token.json', 'w') as token:
            token.write(creds.to_json())
    service = build("drive", "v3", credentials=creds)
    return service



import argparse
from googleapiclient.http import MediaFileUpload
from get_service import get_service


def upload_binary_file_to_drive(file_path, file_name, client_secret_json_filename, parent_folder_id=None):
    service = get_service(client_secret_json_filename)
    media = MediaFileUpload(file_path, mimetype='application/octet-stream')
    file_metadata = {'name': file_name}
    if parent_folder_id:
        file_metadata['parents'] = [parent_folder_id]
    file = service.files().create(body=file_metadata, media_body=media, fields='id').execute()
    print(f'File ID: {file.get("id")}')


if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="Upload a binary file to Google Drive")
    parser.add_argument("file_path", help="The path to the binary file to upload")
    parser.add_argument("file_name", help="The name of the file in Google Drive")
    parser.add_argument("client_secret_file", help="The client secret file (JSON)")
    parser.add_argument("--parent-folder-id", help="The ID of the parent folder in Google Drive")
    args = parser.parse_args()
    # Call the upload function and pass in the Drive API service and optional parent folder ID
    upload_binary_file_to_drive(args.file_path, args.file_name, args.client_secret_file, args.parent_folder_id)



import argparse

from get_service import get_service


def read_file_from_drive(file_id, client_secret_json_filename):
    try:
        service = get_service(client_secret_json_filename)
        request = service.files().get_media(fileId=file_id)
        file_content = request.execute()
        return file_content
    except Exception as e:
        print('Exception, drive_reader.py, read_file_from_drive', e)
        return None


def main():
    parser = argparse.ArgumentParser(description="Read a file from your personal Google Drive account")
    parser.add_argument("file_id", help="The document ID of the file to read")
    parser.add_argument("client_secret_file", help="The client secret file (JSON)")
    args = parser.parse_args()
    file_content = read_file_from_drive(args.file_id, args.client_secret_file)
    if file_content:
        print('file_content', file_content)
    else:
        print("Error reading file")


if __name__ == "__main__":
    main()
